@@ -30,6 +30,8 @@ from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+OptionalRetry = Union[retries.Retry, object]
+
 from google.cloud.webrisk_v1.types import webrisk
 from google.protobuf import timestamp_pb2  # type: ignore
 from .transports.base import WebRiskServiceTransport, DEFAULT_CLIENT_INFO
@@ -340,7 +342,7 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
         threat_type: webrisk.ThreatType = None,
         version_token: bytes = None,
         constraints: webrisk.ComputeThreatListDiffRequest.Constraints = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> webrisk.ComputeThreatListDiffResponse:
@@ -436,7 +438,7 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
         *,
         uri: str = None,
         threat_types: Sequence[webrisk.ThreatType] = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> webrisk.SearchUrisResponse:
@@ -515,7 +517,7 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
         *,
         hash_prefix: bytes = None,
         threat_types: Sequence[webrisk.ThreatType] = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> webrisk.SearchHashesResponse:
@@ -596,7 +598,7 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
         *,
         parent: str = None,
         submission: webrisk.Submission = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> webrisk.Submission:
