@@ -19,13 +19,15 @@ import re
 from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
-import google.api_core.client_options as ClientOptions  # type: ignore
+from google.api_core.client_options import ClientOptions  # type: ignore
 from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+OptionalRetry = Union[retries.Retry, object]
+
 from google.cloud.webrisk_v1beta1.types import webrisk
 from google.protobuf import timestamp_pb2  # type: ignore
 from .transports.base import WebRiskServiceV1Beta1Transport, DEFAULT_CLIENT_INFO
@@ -166,19 +168,19 @@ class WebRiskServiceV1Beta1AsyncClient:
 
     async def compute_threat_list_diff(
         self,
-        request: webrisk.ComputeThreatListDiffRequest = None,
+        request: Union[webrisk.ComputeThreatListDiffRequest, dict] = None,
         *,
         threat_type: webrisk.ThreatType = None,
         version_token: bytes = None,
         constraints: webrisk.ComputeThreatListDiffRequest.Constraints = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> webrisk.ComputeThreatListDiffResponse:
         r"""Gets the most recent threat list diffs.
 
         Args:
-            request (:class:`google.cloud.webrisk_v1beta1.types.ComputeThreatListDiffRequest`):
+            request (Union[google.cloud.webrisk_v1beta1.types.ComputeThreatListDiffRequest, dict]):
                 The request object. Describes an API diff request.
             threat_type (:class:`google.cloud.webrisk_v1beta1.types.ThreatType`):
                 The ThreatList to update.
@@ -258,11 +260,11 @@ class WebRiskServiceV1Beta1AsyncClient:
 
     async def search_uris(
         self,
-        request: webrisk.SearchUrisRequest = None,
+        request: Union[webrisk.SearchUrisRequest, dict] = None,
         *,
         uri: str = None,
         threat_types: Sequence[webrisk.ThreatType] = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> webrisk.SearchUrisResponse:
@@ -270,7 +272,7 @@ class WebRiskServiceV1Beta1AsyncClient:
         given threatList.
 
         Args:
-            request (:class:`google.cloud.webrisk_v1beta1.types.SearchUrisRequest`):
+            request (Union[google.cloud.webrisk_v1beta1.types.SearchUrisRequest, dict]):
                 The request object. Request to check URI entries against
                 threatLists.
             uri (:class:`str`):
@@ -342,11 +344,11 @@ class WebRiskServiceV1Beta1AsyncClient:
 
     async def search_hashes(
         self,
-        request: webrisk.SearchHashesRequest = None,
+        request: Union[webrisk.SearchHashesRequest, dict] = None,
         *,
         hash_prefix: bytes = None,
         threat_types: Sequence[webrisk.ThreatType] = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> webrisk.SearchHashesResponse:
@@ -358,7 +360,7 @@ class WebRiskServiceV1Beta1AsyncClient:
         match of a threat.
 
         Args:
-            request (:class:`google.cloud.webrisk_v1beta1.types.SearchHashesRequest`):
+            request (Union[google.cloud.webrisk_v1beta1.types.SearchHashesRequest, dict]):
                 The request object. Request to return full hashes
                 matched by the provided hash prefixes.
             hash_prefix (:class:`bytes`):
